Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(470)

Unified Diff: third_party/crashpad/crashpad/build/gyp_crashpad.py

Issue 2705373005: Revert of Update Crashpad to 6da9708e7cc93e2e1772439d51646e47583cb225 (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/crashpad/crashpad/build/gyp_crashpad.py
diff --git a/third_party/crashpad/crashpad/build/gyp_crashpad.py b/third_party/crashpad/crashpad/build/gyp_crashpad.py
index fe9da84021b1b970a1e30cb9f6bfddf497b79625..741c8126533fb2462786b7f31a0d40d2c4a19b4a 100755
--- a/third_party/crashpad/crashpad/build/gyp_crashpad.py
+++ b/third_party/crashpad/crashpad/build/gyp_crashpad.py
@@ -31,12 +31,12 @@ def ChooseDependencyPath(local_path, external_path):
external_path: The external path to fall back to.
Returns:
- A 2-tuple. The first element is None or 'external', depending on whether
- local_path or external_path was chosen. The second element is the chosen
- path.
+ A 2-tuple. The first element is 'standalone' or 'external', depending on
+ whether local_path or external_path was chosen. The second element is the
+ chosen path.
"""
if os.path.exists(local_path) or not os.path.exists(external_path):
- return (None, local_path)
+ return ('standalone', local_path)
return ('external', external_path)
@@ -64,8 +64,7 @@ def main(args):
'mini_chromium', 'build', 'common.gypi'),
os.path.join(crashpad_dir, os.pardir, os.pardir, 'mini_chromium',
'mini_chromium', 'build', 'common.gypi')))
- if dependencies is not None:
- args.extend(['-D', 'crashpad_dependencies=%s' % dependencies])
+ args.extend(['-D', 'crashpad_dependencies=%s' % dependencies])
args.extend(['--include', mini_chromium_dir])
args.extend(['--depth', crashpad_dir_or_dot])
args.append(os.path.join(crashpad_dir, 'crashpad.gyp'))

Powered by Google App Engine
This is Rietveld 408576698